marquee documentation
=====================

Contents:

.. toctree::
   :maxdepth: 4

   readme
   installation
   usage
   contributing
   authors
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
